@@ -7,7 +7,7 @@ from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
 import python_on_whales.components.container.cli_wrapper
 from python_on_whales.client_config import DockerCLICaller
-from python_on_whales.components.compose.models import ComposeConfig
+from python_on_whales.components.compose.models import ComposeConfig, ComposeProject
 from python_on_whales.utils import (
     format_dict_for_cli,
     run,
@@ -127,6 +127,7 @@ class ComposeCLI(DockerCLICaller):
         remove_images: Optional[str] = None,
         timeout: Optional[int] = None,
         volumes: bool = False,
+        quiet: bool = False,
     ):
         """Stops and removes the containers
 
@@ -140,6 +141,8 @@ class ComposeCLI(DockerCLICaller):
             volumes: Remove named volumes declared in the
                 volumes section of the Compose file and anonymous
                 volumes attached to containers.
+            quiet: If `False`, send to stderr and stdout the progress spinners with
+                the messages. If `True`, do not display anything.
         """
         full_cmd = self.docker_compose_cmd + ["down"]
         full_cmd.add_flag("--remove-orphans", remove_orphans)
@@ -147,7 +150,7 @@ class ComposeCLI(DockerCLICaller):
         full_cmd.add_simple_arg("--timeout", timeout)
         full_cmd.add_flag("--volumes", volumes)
 
-        run(full_cmd)
+        run(full_cmd, capture_stderr=quiet, capture_stdout=quiet)
 
     def events(self):
         """Not yet implemented"""
@@ -285,9 +288,38 @@ class ComposeCLI(DockerCLICaller):
             full_cmd += to_list(services)
         run(full_cmd)
 
-    def port(self):
-        """Not yet implemented"""
-        raise NotImplementedError
+    def port(
+        self, service: str, private_port: str, index: int = 1, protocol: str = "tcp"
+    ) -> Tuple[Optional[str], Optional[int]]:
+        """Returns the public port for a port binding.
+
+        # Arguments
+            service: The name of the service.
+            private_port: The private port.
+            index: Index of the container if service has multiple replicas (default 1)
+            protocol: tcp or udp (default "tcp").
+
+        # Returns
+            tuple with (host, port). If port is unknown, then host and port are None.
+        """
+        full_cmd = self.docker_compose_cmd + ["port"]
+        if service == "":
+            raise ValueError("Service cannot be empty")
+        if private_port == "":
+            raise ValueError("Private port cannot be empty")
+
+        full_cmd.add_simple_arg("--index", index)
+        full_cmd.add_simple_arg("--protocol", protocol)
+        full_cmd += [service, private_port]
+
+        result = run(full_cmd)
+        if result == ":0":
+            # docker compose cli joins host:str with port:int in the result. If port is unknown
+            # then result has default value for the both variables (str->empty string, int -> 0)
+            return None, None
+
+        host, port = str(result).split(":")
+        return host, int(port)
 
     def ps(self) -> List[python_on_whales.components.container.cli_wrapper.Container]:
         """Returns the containers that were created by the current project.
@@ -306,6 +338,36 @@ class ComposeCLI(DockerCLICaller):
         Container = python_on_whales.components.container.cli_wrapper.Container
         return [Container(self.client_config, x, is_immutable_id=True) for x in ids]
 
+    def ls(
+        self, all: bool = False, filters: Dict[str, str] = {}
+    ) -> List[ComposeProject]:
+        """Returns a list of docker compose projects
+
+        # Arguments
+            all_stopped: Results include all stopped compose projects.
+            project_filters: Filter results based on conditions provided.
+
+        # Returns
+            A `List[python_on_whales.ComposeProject]`
+        """
+        full_cmd = self.docker_compose_cmd + ["ls", "--format", "json"]
+        full_cmd.add_flag("--all", all)
+        full_cmd.add_args_list("--filter", format_dict_for_cli(filters))
+        return [
+            ComposeProject(
+                name=proj["Name"],
+                status=proj["Status"].split("(")[0],
+                count=int(proj["Status"].split("(")[1].strip(")")),
+                config_files=[
+                    Path(path)
+                    for path in proj.get("ConfigFiles", "").split(",")
+                    if "ConfigFiles" in proj
+                ]
+                or None,
+            )
+            for proj in json.loads(run(full_cmd))
+        ]
+
     def pull(
         self,
         services: Union[List[str], str, None] = None,
